@@ -1,26 +1,18 @@
-from __future__ import unicode_literals
-
-import requests
-
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
     OAuth2LoginView,
 )
 
-from .provider import WindowsLiveProvider
-
 
 class WindowsLiveOAuth2Adapter(OAuth2Adapter):
-    provider_id = WindowsLiveProvider.id
-    access_token_url = "https://login.live.com/oauth20_token.srf"
+    provider_id = "windowslive"
+    access_token_url = "https://login.live.com/oauth20_token.srf"  # nosec
     authorize_url = "https://login.live.com/oauth20_authorize.srf"
     profile_url = "https://apis.live.net/v5.0/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {"Authorization": "Bearer {0}".format(token.token)}
-        resp = requests.get(self.profile_url, headers=headers)
-
         # example of what's returned (in python format):
         # {'first_name': 'James', 'last_name': 'Smith',
         #  'name': 'James Smith', 'locale': 'en_US', 'gender': None,
@@ -30,8 +22,11 @@ class WindowsLiveOAuth2Adapter(OAuth2Adapter):
         #  'updated_time': '2014-02-07T00:35:27+0000',
         #  'id': '83605e110af6ff98'}
 
-        resp.raise_for_status()
-        extra_data = resp.json()
+        with get_adapter().get_requests_session() as sess:
+            headers = {"Authorization": f"Bearer {token.token}"}
+            resp = sess.get(self.profile_url, headers=headers)
+            resp.raise_for_status()
+            extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
